CCCBDB VIbrational frequency comparison Page

National Institute of Standards and Technology

Computational Chemistry Comparison and Benchmark DataBase
Release 17b | September 2015
NIST Standard Reference Database 101

I | Introduction
II | Experimental data
III | Calculated data
IV | Data comparisons
V | Cost comparisons
VI | Input and output files
VII | Tutorials and Units
VIII | Links to other sites
IX | Feedback
X | Older CCCBDB versions
XII | Geometries
XIII | Vibrations
XIV | Reaction data
XV | Entropy data
XVI | Bibliographic data
XVII | Ion data
XVIII | Bad calculations
XIX | Index of properties
XX | H-bond dimers
XXI | Oddities

NIST policy on privacy, security, and accessibility.
Please rate our products

© 2013 copyright by the U.S. Secretary of Commerce on behalf of the United States of America. All rights reserved.

The National Institute of Standards and Technology (NIST) is an agency of the U.S. Department of Commerce.

Please send questions, comments, corrections, additions and suggestions to cccbdb@nist.gov.

| # IV.C.1. (XIII.D.1.)

# Compare vibrational frequencies in CCCBDB for C5H12 (Pentane)

### MP2/6-311G*

Frequency in cm-1

| Calculated |  | Experimental
--- | --- | --- | ---
Mode Number | Symmetry | Frequency | diff | Symmetry | Frequency | Comment
1 | A1 | 3004 | 31 | A1 | 2973 |
2 | A1 | 2920 | 28 | A1 | 2892 |
3 | A1 | 2919 | 53 | A1 | 2866 |
4 | A1 | 2901 | 35 | A1 | 2866 |
5 | A1 | 1473 | -7 | A1 | 1480 |
6 | A1 | 1458 | -5 | A1 | 1463 |
7 | A1 | 1448 | -2 | A1 | 1450 |
8 | A1 | 1376 | -3 | A1 | 1379 |
9 | A1 | 1319 | -27 | A1 | 1346 |
10 | A1 | 1127 | -17 | A1 | 1144 |
11 | A1 | 1030 | -6 | A1 | 1036 |
12 | A1 | 851 | -16 | A1 | 867 |
13 | A1 | 386 | -15 | A1 | 401 |
14 | A1 | 172 | -7 | A1 | 179 |
15 | A2 | 3002 | 35 | A2 | 2967 |
16 | A2 | 2958 | 50 | A2 | 2908 |
17 | A2 | 1465 | 3 | A2 | 1462 |
18 | A2 | 1293 | -53 | A2 | 1346 |
19 | A2 | 1231 | -38 | A2 | 1269 |
20 | A2 | 962 | -31 | A2 | 993 |
21 | A2 | 736 | -30 | A2 | 766 |
22 | A2 | 244 | 34 | A2 | 210 |
23 | A2 | 96 | -35 | A2 | 131 |
24 | B1 | 3003 | 38 | B1 | 2965 |
25 | B1 | 2971 | 41 | B1 | 2930 |
26 | B1 | 2939 | 9 | B1 | 2930 |
27 | B1 | 1463 | -6 | B1 | 1469 |
28 | B1 | 1289 | -14 | B1 | 1303 |
29 | B1 | 1175 | 5 | B1 | 1170 |
30 | B1 | 839 | -19 | B1 | 858 |
31 | B1 | 694 | -33 | B1 | 727 |
32 | B1 | 234 | 19 | B1 | 215 |
33 | B1 | 110 | 22 | B1 | 88 |
34 | B2 | 3004 | 39 | B2 | 2965 |
35 | B2 | 2919 | 40 | B2 | 2879 |
36 | B2 | 2914 | 48 | B2 | 2866 |
37 | B2 | 1467 | -9 | B2 | 1476 |
38 | B2 | 1450 | -6 | B2 | 1456 |
39 | B2 | 1374 | -15 | B2 | 1389 |
40 | B2 | 1359 | -20 | B2 | 1379 |
41 | B2 | 1240 | -29 | B2 | 1269 |
42 | B2 | 1058 | -15 | B2 | 1073 |
43 | B2 | 1013 | -11 | B2 | 1024 |
44 | B2 | 906 | -4 | B2 | 910 |
45 | B2 | 384 | -22 | B2 | 406 |
The calculated vibrational frequencies were scaled by 0.9503

See section XIII.C.3 List or set vibrational scaling factors to change the scale factors used here.
See section III.B.3.c Calculate a vibrational scaling factor for a set of molecules to determine the least squares best scaling factor.
See section III.B.3.b List of vibrational scaling factors and their uncertainties for information on where the above scaling factor is from.